@@ -1,8 +1,8 @@
 
 # conditional and unconditional independence tests (vectorized in x, scalar
 # in y).
-indep.test = function(x, y, sx, data, test, B = 0L, alpha = 1, learning = TRUE,
-    complete) {
+indep.test = function(x, y, sx, data, test, B = 0L, alpha = 1,
+  learning = TRUE) {
 
   .Call(call_indep_test,
         x = x,
@@ -13,14 +13,14 @@ indep.test = function(x, y, sx, data, test, B = 0L, alpha = 1, learning = TRUE,
         B = B,
         alpha = alpha,
         learning = learning,
-        complete = complete)
+        complete = attr(data, "metadata")$complete.nodes)
 
 }#INDEP.TEST
 
 # test against all possible subsets of the conditioning set (scalar in both x
 # and y).
 allsubs.test = function(x, y, sx, fixed = character(0), data, test, B = 0L,
-    alpha = 1, min = 0, max = length(sx), complete, debug = FALSE) {
+    alpha = 1, min = 0, max = length(sx), debug = FALSE) {
 
   .Call(call_allsubs_test,
         x = x,
@@ -33,14 +33,14 @@ allsubs.test = function(x, y, sx, fixed = character(0), data, test, B = 0L,
         alpha = alpha,
         min = as.integer(min),
         max = as.integer(min(max, length(sx))),
-        complete = complete,
+        complete = attr(data, "metadata")$complete.nodes,
         debug = debug)
 
 }#ALLSUBS.TEST
 
 # test each variable in turn given the rest as a conditioning set.
 roundrobin.test = function(x, z, fixed, data, test, B = 0L, alpha = 1,
-    complete, debug = FALSE) {
+    debug = FALSE) {
 
   if (length(z) == 0)
     return(structure(numeric(0), names = character(0)))
@@ -53,7 +53,7 @@ roundrobin.test = function(x, z, fixed, data, test, B = 0L, alpha = 1,
         test = test,
         B = B,
         alpha = alpha,
-        complete = complete,
+        complete = attr(data, "metadata")$complete.nodes,
         debug = debug)
 
 }#ROUNDROBIN.TEST
